
function [F2out,fvecout,F2few,fvecfew] = F2smospanew(fvec,F2in,octfrac,fstart,fend,npoints);
% F2smo applies octave-band related smoothing to a squared
% TF magnitude function. A logarithmically spaced output vector
% is generated.
%
% Input parameters:
%	fvec	A vector with the frequencies that correspond to the TF. 
%			They must be equally spaced.
%	F2in	A vector with the squared Tf magnitudes
%	octfrac	The octave band fraction: 1 means octave band, 3 means third octaves etc.
%   fstart	The first frequency of the output vector
%   fend	The last frequency of the output vector
%   npoints	The number of frequnecy values for the output vector
% Output parameters:
%	F2out	The output vector with smoothed squared TF magnitudes
%	fvecout	The frequency values of the output vector
%	F2few	Sampled values of the output vector corresponding to the mid frequencies of the bands
%	fvecfew The frequency values of the F2few vector
%
% Peter Svensson 011126 (svensson@tele.ntnu.no)
%
% [F2out,fvecout,F2few,fvecfew] = F2smospa(fvec,F2in,octfrac,fstart,fend,npoints);

% Based on F2smo, by Johan Nielsen

%-------------------------------------------------

df = fvec(2) - fvec(1);
fvecout = logspace(log10(fstart),log10(fend),npoints);
fvecout = fvecout.';
	nfreqsperdecade = npoints/( log10(fend) - log10(fstart));
	nfreqsperoctave = nfreqsperdecade*log10(2);
	%disp(['   ',num2str(nfreqsperoctave),' output frequency points per octave'])
freqmultfac = 2^(1/(2*octfrac));
flosmo = fvecout/freqmultfac;   iv1 = round(flosmo/df)+1;
fhismo = fvecout*freqmultfac;   iv2 = round(fhismo/df)+1;

ivec = find(iv1<1);
if ~isempty(ivec),
	error(['fstart is too low (',num2str(fstart),')'])
end
ivec = find(iv2 > length(fvec));
if ~isempty(ivec),
	error(['fend is too high (',num2str(fend),')'])
end

F2out = zeros(npoints,1);
F2in = abs(F2in);
for ii=1:npoints,
   F2out(ii) = mean(F2in(iv1(ii):iv2(ii)));
end

%-------------------------------------------------

nstart = round(octfrac/0.3*(log10(fstart)-3));
nend = round(octfrac/0.3*(log10(fend)-3));
fvecfew = 10.^(3 + 0.3/octfrac*([nstart:nend]));

flosmo = fvecfew/freqmultfac;   iv1 = round(flosmo/df)+1;
fhismo = fvecfew*freqmultfac;   iv2 = round(fhismo/df)+1;

ivec = find(iv1<1);
if ~isempty(ivec),
	error(['fstart is too low (',num2str(fstart),')'])
end
ivec = find(iv2 > length(fvec));
if ~isempty(ivec),
	error(['fend is too high (',num2str(fend),')'])
end
nfewpoints = length(fvecfew);

F2few = zeros(nfewpoints,1);
for ii=1:nfewpoints,
   F2few(ii) = mean(F2in(iv1(ii):iv2(ii)));
end



